pub fn prompt_approval(request: &ApprovalRequest) -> ApprovalAnswerExpand description
Display the approval prompt and wait for user input. Returns the user’s answer.
pub fn prompt_approval(request: &ApprovalRequest) -> ApprovalAnswerDisplay the approval prompt and wait for user input. Returns the user’s answer.