pub fn compute_relevance(
entry: &MemoryEntry,
context_keywords: &[String],
) -> f64Expand description
Compute relevance score of a memory entry to context keywords. Returns 0.0-1.0 where 1.0 means highly relevant.
pub fn compute_relevance(
entry: &MemoryEntry,
context_keywords: &[String],
) -> f64Compute relevance score of a memory entry to context keywords. Returns 0.0-1.0 where 1.0 means highly relevant.