pub fn get_lsp_section(servers_info: &[LspServerInfo]) -> Option<String>Expand description
Generate LSP servers info section dynamically
Returns None if no servers are active, otherwise returns the formatted section
pub fn get_lsp_section(servers_info: &[LspServerInfo]) -> Option<String>Generate LSP servers info section dynamically
Returns None if no servers are active, otherwise returns the formatted section