create_provider

Function create_provider 

pub fn create_provider(
    provider_type: ProviderType,
    api_key: String,
    model: String,
    base_url: Option<String>,
) -> Result<Box<dyn Provider>>
Create a provider instance based on type and configuration. This is the recommended way to obtain a Provider instance.