all_tools_with_skills

Function all_tools_with_skills 

pub fn all_tools_with_skills(skills: Arc<Vec<Skill>>) -> Vec<Box<dyn Tool>>
Build the toolset and include the skill tool bound to the given skills catalogue. The catalogue can be empty; the tool still works but will only report “no skills loaded” if invoked.