Module read_history

Module read_history 

Read history tracker for edit/write precondition checks.

Ensures files are read before being modified to prevent accidental overwrites.

Structs

MustReadFirstError
Error type for “must read first” violations.
ReadHistoryTracker
Tracker for files that have been read in the current session.