Agent module - event-driven AI agent implementation.
Provides Agent struct with streaming responses, tool execution, and event output.
Structs
- Agent
- MAX_ITERATIONS Documentation:
- Agent
Builder - Agent builder
Agent module - event-driven AI agent implementation.
Provides Agent struct with streaming responses, tool execution, and event output.